<p align="center">
  <img height="150" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/logo.svg">
</p>
<br/>

<p align="center">
<b>pest</b> <img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/pest.svg" /> is a python <img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/python.svg" /> web application framework designed for constructing scalable APIs, drawing inspiration from <a href="https://docs.nestjs.com/"> nest.js</a> <img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/nestjs.svg" /> and based on <a href="https://fastapi.tiangolo.com/"> fastapi</a> <img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/fastapi.svg" />.
</p>

<br/>

<p align="center">Check the <a href="https://pest.lucode.ar" target="_blank">Documentation</a></p>

<br/>

<p align="center">
  <img height="74" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/latex.svg">
</p>

<br />
<p align="center">
━━━&nbsp&nbsp&nbsp&nbsp<img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/pest.svg" />&nbsp&nbsp&nbsp&nbsp━━━
</p>
<br />

<p align="center">
<img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/pest-py?style=flat-square&logo=python&labelColor=%23020101&color=%23db4a01">&nbsp
<a href="https://pypi.org/project/pest-py/"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/pest-py?style=flat-square&logo=pypi&logoColor=%23db4901&labelColor=%23020101&color=%23db4901&link=https%3A%2F%2Fpypi.org%2Fproject%2Fpest-py%2F"></a>&nbsp
<a href="https://pypi.org/project/pest-py/">
<img alt="PyPI - Version" src="https://img.shields.io/pypi/v/pest-py?style=flat-square&logo=pypi&labelColor=%23020101&color=%23db4a01">
</a>
</p>

<br/>

### Installation

With pip:

```bash
pip install pest-py
```

With poetry:

```bash
poetry add pest-py
```

<br/>

### Quick Start

Head to the [documentation](https://pest.lucode.ar) to learn more about **pest**.

<br/>

### Tutorial

Follow the [tutorial](https://pest.lucode.ar/docs/learn/getting-started) to learn how to build a simple API with **pest**.




